==> respec-34.0.0.tgz: package/README.md <==
# ReSpec

[![Backers on Open Collective](https://opencollective.com/respec/backers/badge.svg)](#backers)
[![Sponsors on Open Collective](https://opencollective.com/respec/sponsors/badge.svg)](#sponsors)
[![Build Status](https://github.com/w3c/respec/workflows/Node%20CI/badge.svg?branch=develop)](https://github.com/w3c/respec/actions?query=workflow%3A%22Node+CI%22+branch%3Adevelop)
[![Website status](https://img.shields.io/github/workflow/status/marcoscaceres/respec.org/Health%20Check?label=respec.org&logo=curl)](https://github.com/marcoscaceres/respec.org/actions?query=workflow%3A%22Health+Check%22)

ReSpec is a JS library that makes it easier to write technical specifications, or documents
that tend to be technical in nature in general. It was originally designed for the purpose
of writing W3C specifications, but has since grown to be able to support other outputs as
well.

## Getting started

If you are just interested in writing a spec, you can grab the [starter spec](examples/starter.html).

We have extensive documentation on [how to use ReSpec](https://github.com/w3c/respec/wiki) in our wiki, including:

  * [User's guide](https://github.com/w3c/respec/wiki/ReSpec-Editor's-Guide)
  * [WebIDL guide](https://github.com/w3c/respec/wiki/WebIDL-Guide)

**You don't need to check-out or fork this repository.**

If you are new to spec writing, we strongly encourage you to read:

  * [API Design Principles](https://w3ctag.github.io/design-principles/)
  * [Writing Promise-Using Specifications](https://www.w3.org/2001/tag/doc/promises-guide)
  * [Privacy and Security Self-Review Questionnaire](https://w3ctag.github.io/security-questionnaire/)
  * [Short i18n review checklist](https://www.w3.org/International/techniques/shortchecklist.html)
  * [Adding another permission? A guide](https://github.com/w3cping/adding-permissions/blob/master/README.md)

## Getting help

If you experience issues, please email [spec-prod@w3.org](mailto:spec-prod@w3.org) or
if you think something is broken, [file a bug](https://github.com/w3c/respec/issues).

**Please note:** ReSpec is not endorsed by W3C and nobody should expect the W3C Webmaster to provide advice on
problems encountered with ReSpec, or on why it may be failing to produce pubrules-compliant
content.

## Bibliographical references

Bibliographical references have been moved out of ReSpec. You want to use
[specref.org](http://www.specref.org/).

## Want to see complete documentation?

[Documentation for ReSpec](https://github.com/w3c/respec/wiki) is available in our wiki.

## Contribute

Please see our [developer guide](https://github.com/w3c/respec/wiki/Developers-Guide).

Please note that this project is released with a [Contributor Code of Conduct](CODE_OF_CONDUCT.md). By participating in this project you agree to abide by its terms.

## Contributors

This project exists thanks to all the people who contribute. [[Contribute](CONTRIBUTING.md)].
<a href="https://github.com/w3c/respec/graphs/contributors"><img src="https://opencollective.com/respec/contributors.svg?width=890&button=false" /></a>


## Backers

Thank you to all our backers! 🙏 [[Become a backer](https://opencollective.com/respec#backer)]

<a href="https://opencollective.com/respec#backers" target="_blank"><img src="https://opencollective.com/respec/backers.svg?width=890"></a>


## Sponsors

Support this project by becoming a sponsor. Your logo will show up here with a link to your website. [[Become a sponsor](https://opencollective.com/respec#sponsor)]

<a href="https://opencollective.com/respec/sponsor/0/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/0/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/1/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/1/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/2/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/2/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/3/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/3/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/4/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/4/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/5/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/5/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/6/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/6/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/7/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/7/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/8/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/8/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/9/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/9/avatar.svg"></a>

==> respec-35.1.0.tgz: package/README.md <==
# ReSpec

[![Backers on Open Collective](https://opencollective.com/respec/backers/badge.svg)](#backers)
[![Sponsors on Open Collective](https://opencollective.com/respec/sponsors/badge.svg)](#sponsors)
[![Build Status](https://github.com/speced/respec/workflows/Node%20CI/badge.svg?branch=develop)](https://github.com/speced/respec/actions?query=workflow%3A%22Node+CI%22+branch%3Adevelop)
[![Website status](https://img.shields.io/github/workflow/status/marcoscaceres/respec.org/Health%20Check?label=respec.org&logo=curl)](https://github.com/marcoscaceres/respec.org/actions?query=workflow%3A%22Health+Check%22)

ReSpec is a JS library that makes it easier to write technical specifications, or documents
that tend to be technical in nature in general. It was originally designed for the purpose
of writing W3C specifications, but has since grown to be able to support other outputs as
well.

## Getting started

If you are just interested in writing a spec, you can grab the [starter spec](examples/starter.html).

We have extensive documentation on [how to use ReSpec](https://github.com/speced/respec/wiki) in our wiki, including:

  * [User's guide](https://github.com/speced/respec/wiki/ReSpec-Editor's-Guide)
  * [WebIDL guide](https://github.com/speced/respec/wiki/WebIDL-Guide)

**You don't need to check-out or fork this repository.**

If you are new to spec writing, we strongly encourage you to read:

  * [API Design Principles](https://w3ctag.github.io/design-principles/)
  * [Writing Promise-Using Specifications](https://www.w3.org/2001/tag/doc/promises-guide)
  * [Privacy and Security Self-Review Questionnaire](https://w3ctag.github.io/security-questionnaire/)
  * [Short i18n review checklist](https://www.w3.org/International/techniques/shortchecklist.html)
  * [Adding another permission? A guide](https://github.com/w3cping/adding-permissions/blob/master/README.md)

## Getting help

If you experience issues, please email [spec-prod@w3.org](mailto:spec-prod@w3.org) or
if you think something is broken, [file a bug](https://github.com/speced/respec/issues).

**Please note:** ReSpec is not endorsed by W3C and nobody should expect the W3C Webmaster to provide advice on
problems encountered with ReSpec, or on why it may be failing to produce pubrules-compliant
content.

## Bibliographical references

Bibliographical references have been moved out of ReSpec. You want to use
[specref.org](http://www.specref.org/).

## Want to see complete documentation?

[Documentation for ReSpec](https://github.com/speced/respec/wiki) is available in our wiki.

## Contribute

Please see our [developer guide](https://github.com/speced/respec/wiki/Developers-Guide).

Please note that this project is released with a [Contributor Code of Conduct](CODE_OF_CONDUCT.md). By participating in this project you agree to abide by its terms.

## Contributors

This project exists thanks to all the people who contribute. [[Contribute](CONTRIBUTING.md)].
<a href="https://github.com/speced/respec/graphs/contributors"><img src="https://opencollective.com/respec/contributors.svg?width=890&button=false" /></a>


## Backers

Thank you to all our backers! 🙏 [[Become a backer](https://opencollective.com/respec#backer)]

<a href="https://opencollective.com/respec#backers" target="_blank"><img src="https://opencollective.com/respec/backers.svg?width=890"></a>


## Sponsors

Support this project by becoming a sponsor. Your logo will show up here with a link to your website. [[Become a sponsor](https://opencollective.com/respec#sponsor)]

<a href="https://opencollective.com/respec/sponsor/0/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/0/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/1/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/1/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/2/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/2/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/3/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/3/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/4/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/4/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/5/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/5/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/6/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/6/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/7/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/7/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/8/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/8/avatar.svg"></a>
<a href="https://opencollective.com/respec/sponsor/9/website" target="_blank"><img src="https://opencollective.com/respec/sponsor/9/avatar.svg"></a>
